Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6647)

Unified Diff: chrome/browser/ui/views/frame/browser_view.h

Issue 63173016: DevTools: place DevTools WebContents underneath inspected WebContents. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/browser_view.h
diff --git a/chrome/browser/ui/views/frame/browser_view.h b/chrome/browser/ui/views/frame/browser_view.h
index a053d2c52164c61dbd64cfd4f7f649c2bc61687c..80456616caa7e359332227549a98a6c3000b5731 100644
--- a/chrome/browser/ui/views/frame/browser_view.h
+++ b/chrome/browser/ui/views/frame/browser_view.h
@@ -46,6 +46,7 @@ class BookmarkBarView;
class Browser;
class BrowserViewLayout;
class ContentsContainer;
+class DevToolsContainer;
class DownloadShelfView;
class FullscreenExitBubbleViews;
class InfoBarContainerView;
@@ -456,10 +457,12 @@ class BrowserView : public BrowserWindow,
virtual void OnOmniboxPopupShownOrHidden() OVERRIDE;
// Testing interface:
- views::SingleSplitView* GetContentsSplitForTest() { return contents_split_; }
ContentsContainer* GetContentsContainerForTest() {
return contents_container_;
}
+ DevToolsContainer* GetDevToolsContainerForTest() {
+ return devtools_container_;
+ }
views::WebView* GetContentsWebViewForTest() { return contents_web_view_; }
private:
@@ -518,16 +521,6 @@ class BrowserView : public BrowserWindow,
// sure devtools window size and position are restored for given tab.
void UpdateDevToolsForContents(content::WebContents* web_contents);
- // Shows docked devtools.
- void ShowDevToolsContainer();
-
- // Hides docked devtools.
- void HideDevToolsContainer();
-
- // Reads split position from the current tab's devtools window and applies
- // it to the devtools split.
- void UpdateDevToolsSplitPosition();
-
// Updates various optional child Views, e.g. Bookmarks Bar, Info Bar or the
// Download Shelf in response to a change notification from the specified
// |contents|. |contents| can be NULL. In this case, all optional UI will be
@@ -611,16 +604,14 @@ class BrowserView : public BrowserWindow,
// |------------------------------------------------------------------|
// | Bookmarks (bookmark_bar_view_) [1] |
// |------------------------------------------------------------------|
- // | Debugger splitter (contents_split_) |
+ // | Contents (contents_container_) |
// | -------------------------------------------------------------- |
- // | | Page content (contents_container_) | |
+ // | | DevTools container (devtools_container_) | |
// | | -------------------------------------------------------- | |
// | | | contents_web_view_ | | |
// | | -------------------------------------------------------- | |
- // | -------------------------------------------------------------- |
- // | -------------------------------------------------------------- |
- // | | Debugger (devtools_container_) | |
- // | | | |
+ // | | | devtools_web_view_ | | |
+ // | | -------------------------------------------------------- | |
// | -------------------------------------------------------------- |
// |------------------------------------------------------------------|
// | Active downloads (download_shelf_) |
@@ -667,24 +658,21 @@ class BrowserView : public BrowserWindow,
views::WebView* contents_web_view_;
// The view that contains devtools window for the selected WebContents.
- views::WebView* devtools_container_;
+ views::WebView* devtools_web_view_;
- // The view managing the |contents_web_view_|.
- ContentsContainer* contents_container_;
+ // The view managing devtools and contents windows relative positions.
+ DevToolsContainer* devtools_container_;
- // Split view containing the contents container and devtools container.
- views::SingleSplitView* contents_split_;
-
- // Side to dock devtools to.
- DevToolsDockSide devtools_dock_side_;
+ // The view managing the |devtools_container_|.
+ ContentsContainer* contents_container_;
// Docked devtools window instance. NULL when current tab is not inspected
// or is inspected with undocked version of DevToolsWindow.
DevToolsWindow* devtools_window_;
// Tracks and stores the last focused view which is not the
// devtools_container_ or any of its children. Used to restore focus once
// the devtools_container_ is hidden.
scoped_ptr<views::ExternalFocusTracker> devtools_focus_tracker_;
// The Status information bubble that appears at the bottom of the window.
@@ -667,24 +658,21 @@ class BrowserView : public BrowserWindow,
DevToolsWindow* devtools_window_;
// Tracks and stores the last focused view which is not the
- // devtools_container_ or any of its children. Used to restore focus once
- // the devtools_container_ is hidden.
+ // devtools_web_view_ or any of its children. Used to restore focus once
+ // the devtools_web_view_ is hidden.
scoped_ptr<views::ExternalFocusTracker> devtools_focus_tracker_;
// The Status information bubble that appears at the bottom of the window.

Powered by Google App Engine
This is Rietveld 408576698